%AnalyzeGroupData.m
%Created 9/5/18 by A. Bosen
%
%This script loads data for all subjects it can find

%This is needed for the ex-Gauss fit
addpath('.\exgauss estimation'); 

dataDirectories = dir(['Experiment Results' filesep 'NH_A_*']);

crossConditionVariableNames = {'subjectID', 'condition', 'percentCorrect', 'meanRT', 'mu', 'sigma', 'tau'};
crossConditionStatistics = cell2table(cell(0,length(crossConditionVariableNames)), 'VariableNames', crossConditionVariableNames);

for(subjectIndex = 1:length(dataDirectories))
	dataDirectory = [dataDirectories(subjectIndex).folder filesep dataDirectories(subjectIndex).name filesep];
	dataFiles = dir([dataDirectory 'colorshapetask_raw_*.iqdat']);
	if(~isempty(dataFiles))
		
		allSubjectData = [];
		for(fileIndex = 1:length(dataFiles))
			data = readtable([dataFiles(fileIndex).folder filesep dataFiles(fileIndex).name],'filetype','text');
			if(isempty(allSubjectData))
				allSubjectData = data;
			else
				allSubjectData = [allSubjectData;data];
			end
		end


		experimentData = allSubjectData(strcmp(allSubjectData.blockcode,'mixed_Word_shortCSI'),:);
		%Remove the instructions, first task, and rest period
		experimentData = experimentData(~strcmp(experimentData.trialcode,'MixedTestInstruct'),:);
		experimentData = experimentData(~strcmp(experimentData.trialcode,'mixed_firsttask'),:);
		experimentData = experimentData(~strcmp(experimentData.trialcode,'Rest'),:);

		%keyMappings = {'Consistent','Inconsistent'};
		shiftTask = {'Repeat','Shift'};
		for(taskIndex = 1:length(shiftTask))
			conditionRTs = experimentData.latency(strcmp(experimentData.values_mixed_shifttask,shiftTask(taskIndex)) &...
					experimentData.correct == 1);
			outlierCutoff = mean(conditionRTs) + 4 * std(conditionRTs);
			allOutliers = [];
			%Low end cutoff is fixed at 200 ms, as in Schmiedek et al. 2007
			outliers = conditionRTs(conditionRTs < 200);
			allOutliers = [allOutliers;outliers];
			conditionRTs(conditionRTs < 200) = [];
			while(any(conditionRTs > outlierCutoff))
				outliers = conditionRTs(conditionRTs > outlierCutoff);
				disp(['RTs labeled as outliers: ' num2str(outliers')]);
				allOutliers = [allOutliers;outliers];
				conditionRTs(conditionRTs > outlierCutoff) = []; 
				outlierCutoff = mean(conditionRTs) + 4 * std(conditionRTs);
			end
			percentCorrect(taskIndex) = mean(experimentData.correct(strcmp(experimentData.values_mixed_shifttask,shiftTask(taskIndex))));
			exGaussParams(taskIndex,:) = exgauss_fit(conditionRTs);
			meanRT(taskIndex) = geomean(conditionRTs);
		end
		statTable = table(repmat({dataDirectories(subjectIndex).name},length(shiftTask),1),...
			shiftTask',...
			percentCorrect',...
			meanRT',...
			exGaussParams(:,1),...
			exGaussParams(:,2),...
			exGaussParams(:,3),...
			'VariableNames', crossConditionVariableNames);

		%Save results to a single table
		crossConditionStatistics = [crossConditionStatistics; statTable];
	end

end

%Plot the change in each summary statistic across task conditions
subjects = unique(crossConditionStatistics.subjectID);
for(metricIndex = 3:width(crossConditionStatistics))

	figure;
	hold on;
	%Thin line for each subject
	for(subjectIndex = 1:length(subjects))
		repeatMetric(subjectIndex) = crossConditionStatistics{strcmp('Repeat',crossConditionStatistics.condition) &...
						strcmp(subjects{subjectIndex},crossConditionStatistics.subjectID),metricIndex};
		shiftMetric(subjectIndex) = crossConditionStatistics{strcmp('Shift',crossConditionStatistics.condition) &...
						strcmp(subjects{subjectIndex},crossConditionStatistics.subjectID),metricIndex};
		plot(1:2, [repeatMetric(subjectIndex), shiftMetric(subjectIndex)],'-','Color',[0.2 0.2 0.2],'LineWidth',1);
	end
	%Thick line for group mean
	plot(1:2, [geomean(repeatMetric) geomean(shiftMetric)],'k-','LineWidth',3);
	signrank(repeatMetric,shiftMetric)
	if(metricIndex == 4)
		%Special condition to ensure consistency for the mean RT plot across tasks
		axis([0.5 2.5 0 2200]);
	else
		axis([0.5 2.5 0 max(crossConditionStatistics{:,metricIndex})*1.05]);
	end
	ylabel(crossConditionStatistics.Properties.VariableNames(metricIndex));
	set(gca,'FontSize',18);
	set(gcf,'PaperUnits','inches','PaperPosition',[0 0 4 5]);
	box off;
	xticks(1:2);
	xticklabels({'Repeat', 'Shift'});
	outputFileName = ['.\Figures\Color Shape Group Change in ' crossConditionStatistics.Properties.VariableNames{metricIndex} ' Across Listening Conditions'];
	print(outputFileName,'-dpng','-r600');
end
