subjectID = 'NH_A_82';
dataFiles = dir(['Experiment Results' filesep subjectID filesep 'colorshapetask_raw_' subjectID '*']);

addpath('exgauss estimation');

allData = [];
for(fileIndex = 1:length(dataFiles))
	data = readtable([dataFiles(fileIndex).folder filesep dataFiles(fileIndex).name],'filetype','text');
	if(isempty(allData))
		allData = data;
	else
		allData = [allData;data];
	end
end

experimentData = allData(strcmp(allData.blockcode,'mixed_Word_shortCSI'),:);
%Remove the instructions, first task, and rest period
experimentData = experimentData(~strcmp(experimentData.trialcode,'MixedTestInstruct'),:);
experimentData = experimentData(~strcmp(experimentData.trialcode,'mixed_firsttask'),:);
experimentData = experimentData(~strcmp(experimentData.trialcode,'Rest'),:);

%keyMappings = {'Consistent','Inconsistent'};
shiftTask = {'Repeat','Shift'};
figure;
for(taskIndex = 1:length(shiftTask))
	subplot(length(shiftTask),1,taskIndex);
	conditionRTs = experimentData.latency(strcmp(experimentData.values_mixed_shifttask,shiftTask(taskIndex)) &...
       			experimentData.correct == 1);
	outlierCutoff = mean(conditionRTs) + 4 * std(conditionRTs);
	allOutliers = [];
	while(any(conditionRTs > outlierCutoff))
		outliers = conditionRTs(conditionRTs > outlierCutoff);
		disp(['RTs labeled as outliers: ' num2str(outliers)]);
		allOutliers = [allOutliers;outliers];
		conditionRTs(conditionRTs > outlierCutoff) = []; 
		outlierCutoff = mean(conditionRTs) + 4 * std(conditionRTs);
	end
	[X] = exgauss_fit(conditionRTs)
	histogram(conditionRTs, 'Normalization','pdf','BinWidth',50,'FaceColor',[0.5 0.5 0.5]);
	hold on;
	plot([geomean(conditionRTs) geomean(conditionRTs)], [0 1],'k--','Linewidth',2);
	disp(['Geometric mean RT for ' shiftTask{taskIndex} ' was ' num2str(geomean(conditionRTs))]);
	plot([allOutliers allOutliers]', [zeros(size(allOutliers)) ones(size(allOutliers))]','r-');
	pdf = exgauss_pdf(0:2500,[X]);
	plot(0:2500,pdf,'k-','Linewidth',2);
	title(shiftTask{taskIndex});
	set(gca,'FontSize',20);
	yticks([]);
	box off;
end
xlabel('Reaction Time (ms)');
ylabel('Probability');
linkaxes;
axis([(min(experimentData.latency) - 50) (max(experimentData.latency) + 50) 0 0.0031]);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 7.75 7.5]);
outputFileName = ['.\Figures\' subjectID ' Color Shape Response Latency'];
print(outputFileName,'-dpng','-r600');
