%PlotRTScatter.m
%Created 12/5/19 by A. Bosen
%
%This script loads data for all subjects it can find

dataDirectories = dir(['Experiment Results' filesep 'NH_A_*']);

plotColors = 	[0   0   0;...
		 0.5 0.5 0.5];

figure;
hold on;
for(subjectIndex = 1:length(dataDirectories))
	dataDirectory = [dataDirectories(subjectIndex).folder filesep dataDirectories(subjectIndex).name filesep];
	dataFiles = dir([dataDirectory 'colorshapetask_raw_*.iqdat']);
	if(~isempty(dataFiles))
		
		allSubjectData = [];
		for(fileIndex = 1:length(dataFiles))
			data = readtable([dataFiles(fileIndex).folder filesep dataFiles(fileIndex).name],'filetype','text');
			if(isempty(allSubjectData))
				allSubjectData = data;
			else
				allSubjectData = [allSubjectData;data];
			end
		end


		experimentData = allSubjectData(strcmp(allSubjectData.blockcode,'mixed_Word_shortCSI'),:);
		%Remove the instructions, first task, and rest period
		experimentData = experimentData(~strcmp(experimentData.trialcode,'MixedTestInstruct'),:);
		experimentData = experimentData(~strcmp(experimentData.trialcode,'mixed_firsttask'),:);
		experimentData = experimentData(~strcmp(experimentData.trialcode,'Rest'),:);

		%keyMappings = {'Consistent','Inconsistent'};
		shiftTask = {'Repeat','Shift'};
		for(taskIndex = 1:length(shiftTask))
			conditionRTs = experimentData.latency(strcmp(experimentData.values_mixed_shifttask,shiftTask(taskIndex)) &...
					experimentData.correct == 1);
			outlierCutoff = mean(conditionRTs) + 4 * std(conditionRTs);
			allOutliers = [];
			%Low end cutoff is fixed at 200 ms, as in Schmiedek et al. 2007
			outliers = conditionRTs(conditionRTs < 200);
			allOutliers = [allOutliers;outliers];
			conditionRTs(conditionRTs < 200) = [];
			while(any(conditionRTs > outlierCutoff))
				outliers = conditionRTs(conditionRTs > outlierCutoff);
				disp(['RTs labeled as outliers: ' num2str(outliers')]);
				allOutliers = [allOutliers;outliers];
				conditionRTs(conditionRTs > outlierCutoff) = []; 
				outlierCutoff = mean(conditionRTs) + 4 * std(conditionRTs);
			end
			percentCorrect(taskIndex) = mean(experimentData.correct(strcmp(experimentData.values_mixed_shifttask,shiftTask(taskIndex))));
			meanRT(taskIndex) = geomean(conditionRTs);

			%Scatter data
			plot((6*(subjectIndex-1)+taskIndex)*ones(1,length(conditionRTs)),conditionRTs,'.','color',plotColors(taskIndex,:),'MarkerSize',10);
			%Scatter outliers
			plot((6*(subjectIndex-1)+taskIndex)*ones(1,length(allOutliers)),allOutliers,'o','color',plotColors(taskIndex,:),'MarkerSize',2);
			%Plot mean
			plot((6*(subjectIndex-1)+taskIndex) + [-1 1],repmat(meanRT(taskIndex),2,1),'color',plotColors(taskIndex,:),'Linewidth',6);
		end 
	end

end 

xlabel('Participant');
ylabel('Reaction Time (ms)');
axis([-2 228 0 3400]);
yticks(0:500:5000);
xticks(1.5:6:223.5);
xticklabels([]);
set(gca,'FontSize',20);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 16.5 8]);
box on;
outputFileName = ['.\Figures\Group ColorShape RT data scatter'];
print(outputFileName,'-dpng','-r600');

