subjectID = 'NH_A_82';
dataFiles = dir(['Experiment Results' filesep subjectID filesep 'stroopwithcontrolkeyboard_raw*']);

addpath('exgauss estimation');

allData = [];
for(fileIndex = 1:length(dataFiles))
	data = readtable([dataFiles(fileIndex).folder filesep dataFiles(fileIndex).name],'filetype','text');
	if(isempty(allData))
		allData = data;
	else
		allData = [allData;data];
	end
end

congruencyTypes = unique(allData.values_congruency);
congruencyTypeNames = {'Congruent', 'Incongruent', 'Neutral'};
figure;
for(congruencyIndex = congruencyTypes')
	subplot(length(congruencyTypes),1,congruencyIndex);
	conditionRTs = allData.latency(allData.values_congruency == congruencyIndex & allData.correct == 1);
	outlierCutoff = mean(conditionRTs) + 4 * std(conditionRTs);
	allOutliers = [];
	while(any(conditionRTs > outlierCutoff))
		outliers = conditionRTs(conditionRTs > outlierCutoff);
		disp(['RTs labeled as outliers: ' num2str(outliers')]);
		allOutliers = [allOutliers;outliers];
		conditionRTs(conditionRTs > outlierCutoff) = []; 
		outlierCutoff = mean(conditionRTs) + 4 * std(conditionRTs);
	end
	X = exgauss_fit(conditionRTs);
	plot([median(conditionRTs) median(conditionRTs)], [0 1],'k--');
	disp(['Median RT for ' congruencyTypeNames{congruencyIndex} ' was ' num2str(median(conditionRTs))]);
	hold on;
	plot([allOutliers allOutliers]', [zeros(size(allOutliers)) ones(size(allOutliers))]','r-');
	pdf = exgauss_pdf(0:2500,X);
	plot(0:2500,pdf,'k-');
	histogram(conditionRTs, 'Normalization','pdf','BinWidth',50,'FaceColor',[0.5 0.5 0.5]);
	title(congruencyTypeNames{congruencyIndex});
	set(gca,'FontSize',20);
	yticks([]);
	box off;
end
xlabel('Reaction Time (ms)');
ylabel('Probability');
linkaxes;
axis([(min(allData.latency) - 50) (max(allData.latency) + 50) 0 0.0043]);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 6 8]);
outputFileName = ['.\Figures\' subjectID ' Stroop Response Latency'];
print(outputFileName,'-dpng','-r600');
