%PlotRTScatter.m
%Created 12/5/19 by A. Bosen
%
%This script loads data for all subjects it can find

dataDirectories = dir(['Experiment Results' filesep 'NH_A_*']);


plotColors = 	[0   0   0;...
		 0.3 0.3 0.3;...
		 0.6 0.6 0.6];
figure;
hold on;
for(subjectIndex = 1:length(dataDirectories))
	dataDirectory = [dataDirectories(subjectIndex).folder filesep dataDirectories(subjectIndex).name filesep];
	dataFiles = dir([dataDirectory 'stroopwithcontrolkeyboard_raw*.iqdat']);
	if(~isempty(dataFiles))
		
		allSubjectData = [];
		for(fileIndex = 1:length(dataFiles))
			data = readtable([dataFiles(fileIndex).folder filesep dataFiles(fileIndex).name],'filetype','text');
			if(isempty(allSubjectData))
				allSubjectData = data;
			else
				allSubjectData = [allSubjectData;data];
			end
		end

		congruencyTypes = unique(allSubjectData.values_congruency);
		congruencyTypeNames = {'Congruent', 'Incongruent', 'Neutral'};
		for(congruencyIndex = congruencyTypes')
			conditionRTs = allSubjectData.latency(allSubjectData.values_congruency == congruencyIndex & allSubjectData.correct == 1);
			outlierCutoff = mean(conditionRTs) + 4 * std(conditionRTs);
			allOutliers = [];
			%Low end cutoff is fixed at 200 ms, as in Schmiedek et al. 2007
			outliers = conditionRTs(conditionRTs < 200);
			allOutliers = [allOutliers;outliers];
			conditionRTs(conditionRTs < 200) = [];
			while(any(conditionRTs > outlierCutoff))
				outliers = conditionRTs(conditionRTs > outlierCutoff);
				disp(['RTs labeled as outliers: ' num2str(outliers')]);
				allOutliers = [allOutliers;outliers];
				conditionRTs(conditionRTs > outlierCutoff) = []; 
				outlierCutoff = mean(conditionRTs) + 4 * std(conditionRTs);
			end
			percentCorrect(congruencyIndex) = mean(allSubjectData.correct(allSubjectData.values_congruency == congruencyIndex));
			meanRT(congruencyIndex) = geomean(conditionRTs);

			plotPosition = [2 3 1]; %This is needed to ensure netural, congruent, and incongruent get plotted in that order
			%Scatter data
			plot((6*(subjectIndex-1)+plotPosition(congruencyIndex))*ones(1,length(conditionRTs)),conditionRTs,'.','color',plotColors(plotPosition(congruencyIndex),:),'MarkerSize',10);
			%Scatter outliers
			plot((6*(subjectIndex-1)+plotPosition(congruencyIndex))*ones(1,length(allOutliers)),allOutliers,'o','color',plotColors(plotPosition(congruencyIndex),:),'MarkerSize',2);
			%Plot mean
			plot((6*(subjectIndex-1)+plotPosition(congruencyIndex)) + [-1 1],repmat(meanRT(congruencyIndex),2,1),'color',plotColors(plotPosition(congruencyIndex),:),'Linewidth',6);
		end

		
	end

end

xlabel('Participant');
ylabel('Reaction Time (ms)');
axis([-2 228 0 3400]);
yticks(0:500:5000);
xticks(2:6:224);
xticklabels([]);
set(gca,'FontSize',20);
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 16.5 8]);
box on;
outputFileName = ['.\Figures\Group Stroop RT data scatter'];
print(outputFileName,'-dpng','-r600');

