%CalculateDigitTrialStatistics.m
%
%Created 11/30/17 by A. Bosen
%This function goes through each trial of Digit span data and calculates the number of digits
%that were correct repeated, along with whether the entire trial was correct
%The returned data structure is a modified version of the input, with added columns that include statistics

function [dataWithStatistics] = CalculateDigitTrialStatistics(data) 

	%Build an index to easily retrieve all the data from a trial
	maxSpanLength = max(data.NumberOfDigits);
	%Find the columns labeled 'DigitSequence' and 'Response'
	sequenceStartColumn = find(strcmp(data.Properties.VariableNames,'DigitSequence'));
	responseStartColumn = find(strcmp(data.Properties.VariableNames,'Response'));
	sequenceIndex = sequenceStartColumn:sequenceStartColumn+maxSpanLength-1;
	responseIndex = responseStartColumn:responseStartColumn+maxSpanLength-1;

	%Some subjects never responded with a full list of nine items,
	%so we need to add NaNs to the ninth digit column
	if(max(responseIndex) > size(data,2))
		data = [data array2table(nan(size(data,1),max(responseIndex) - size(data,2)))];
	end

	%Go through the data for each trial, calculate summary results of each trial
	for(trialIndex = 1:size(data,1))
		sequence = data{trialIndex,sequenceIndex};
		response = data{trialIndex,responseIndex};
		%for digitPositions, the row is the item number and the column is what position that item was found in,
		%i.e. a 1 at (1,2) means that the second item in the sequence was given as the first item in the response
		digitPositions = zeros(maxSpanLength);
		digitPositions(find(sequence == response')) = 1;
		data.digitPositions(trialIndex) = {digitPositions};
		%Replace all nans with zeroes, to make comparison easier
		sequence(isnan(sequence)) = 0;
		response(isnan(response)) = 0;
		data.digitsCorrect(trialIndex) = {sequence(1:data.NumberOfDigits(trialIndex)) == response(1:data.NumberOfDigits(trialIndex))};
		data.correctResponse(trialIndex) = all(data.digitsCorrect{trialIndex});
		data.ndigitsCorrect(trialIndex) = sum(data.digitsCorrect{trialIndex});
	end
	dataWithStatistics = data;

end 
