%LoadSubjectData.m
%Created 11/30/17 by A. Bosen
%
%This function loads all data files that match the input string pattern and
%concatenates the results into a single table
function [data] = LoadSubjectData(dataPathPattern)
	dataFiles = dir(dataPathPattern);

	%Load all of the data for this subject and experiment type
	data = table();
	for(fileIndex = 1:length(dataFiles))
		newData = readtable([dataFiles(fileIndex).folder '\' dataFiles(fileIndex).name]);
		%Check if we need to add dummy columns to old data file
		if(~isempty(data) & (size(newData,2) > size(data,2)))
			data = AddDummyColumns(data,newData);	
		%check if we need to add dummy columns to the new data file
		elseif(~isempty(data) & (size(newData,2) < size(data,2)))
			newData = AddDummyColumns(newData,data);
		end
		data = [data ; newData];
	end

end

function dataWithDummyColumns = AddDummyColumns(data,template)
	%Cell arrays and non-cell arrays can't be concatenated, so check the variable type in the template
	if(iscell(template{:,(end + 1 - (size(template,2) - size(data,2))):end}))
		dummyColumn = cell(size(data,1),size(template,2) - size(data,2));
		dummyColumn(:) = {''};
		dataWithDummyColumns = [data array2table(dummyColumn)];
	else
		dataWithDummyColumns = [data array2table(nan(size(data,1),size(template,2) - size(data,2)))];
	end
	dataWithDummyColumns.Properties.VariableNames = template.Properties.VariableNames;
end
