%ValidateResponseScoring.m
%Created 12/10/19 by A. Bosen
%
%This script looks for folders called 'PRESTO Scoring Confirmation' in each subject's
%results, and compares the accuracy for each item from that folder with the primary data

dataDirectories = dir('.\Experiment Results\NH_A_*');

validationKeywordsCorrect = nan(36,length(dataDirectories));
validationPercentCorrect = nan(36,1);
dataKeywordsCorrect = nan(36,length(dataDirectories));
dataPercentCorrect = nan(36,1);

for(subjectIndex = 1:length(dataDirectories))
	dataDirectory = [dataDirectories(subjectIndex).folder filesep dataDirectories(subjectIndex).name filesep];

	%Check to see if we have validation data for this individual
	validationString = [dataDirectory 'PRESTO Scoring Confirmation' filesep '*.xlsx'];
	if(~isempty(dir(validationString)))
		validationData = LoadSubjectData(validationString);
		validationKeywordsCorrect(:,subjectIndex) = validationData.x_Correct;
		validationPercentCorrect(subjectIndex) = sum(validationData.x_Correct) / sum(validationData.x_Keywords);

		%If so, load the matched file from the main folder
		validationFileStruct = dir(validationString);
		dataString = [dataDirectory validationFileStruct.name];
		data = LoadSubjectData(dataString);
		dataKeywordsCorrect(:,subjectIndex) = data.x_Correct;
		dataPercentCorrect(subjectIndex) = sum(data.x_Correct) / sum(data.x_Keywords); 
	end

end

%Calculate agreement
nKeywordsAgreement = sum(abs(dataKeywordsCorrect - validationKeywordsCorrect))
sentenceAgreement = mean(validationKeywordsCorrect == dataKeywordsCorrect);
sentenceAgreement(isnan(validationPercentCorrect)) = nan
percentCorrectAgreement = dataPercentCorrect - validationPercentCorrect

disp(['Mean Number of keywords that differed: ' num2str(mean(nKeywordsAgreement,'omitnan'))]);
disp(['Mean absolute percent correct difference: ' num2str(mean(abs(percentCorrectAgreement),'omitnan'))]);
